pub struct ImageTemplateShellValidator {
pub image_template_in_vm_validator: ImageTemplateInVmValidator,
pub script_uri: Option<String>,
pub sha256_checksum: Option<String>,
pub inline: Vec<String>,
}Expand description
Runs the specified shell script during the validation phase (Linux). Corresponds to Packer shell provisioner. Exactly one of ‘scriptUri’ or ‘inline’ can be specified.
Fields
image_template_in_vm_validator: ImageTemplateInVmValidatorscript_uri: Option<String>URI of the shell script to be run for validation. It can be a github link, Azure Storage URI, etc
sha256_checksum: Option<String>SHA256 checksum of the shell script provided in the scriptUri field
inline: Vec<String>Array of shell commands to execute
Implementations
Sourceimpl ImageTemplateShellValidator
impl ImageTemplateShellValidator
pub fn new(image_template_in_vm_validator: ImageTemplateInVmValidator) -> Self