ImageTemplateSharedImageVersionSource

Struct ImageTemplateSharedImageVersionSource 

pub struct ImageTemplateSharedImageVersionSource {
    pub image_version_id: String,
    pub exact_version: Option<String>,
}
Describes an image source that is an image version in an Azure Compute Gallery or a Direct Shared Gallery.

Fields

image_version_id: String

ARM resource id of the image version. When image version name is ‘latest’, the version is evaluated when the image build takes place.

exact_version: Option<String>

Exact ARM resource id of the image version. This readonly field differs from the image version Id in ‘imageVersionId’ only if the version name specified in ‘imageVersionId’ field is ‘latest’.

Implementations

Source

impl ImageTemplateSharedImageVersionSource

pub fn new(image_version_id: String) -> Self